<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.devpri.com
 * @since      1.0.0
 *
 * @package    Devpri_Custom_Code
 * @subpackage Devpri_Custom_Code/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Devpri_Custom_Code
 * @subpackage Devpri_Custom_Code/admin
 * @author     Devpri <contact@devpri.com>
 */
class Devpri_Custom_Code_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * The custom post type of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 */
	protected $post_type;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {
		$this->plugin_name = $plugin_name;
		$this->version = $version;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Devpri_Custom_Code_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Devpri_Custom_Code_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'assets/css/devpri-custom-code-admin.css', array(), $this->version, 'all' );
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

        wp_enqueue_code_editor( array( 'type' => 'text/html' ) );

		wp_enqueue_script( 'dcc-post', plugin_dir_url( __FILE__ ) . 'assets/js/dcc-post.js', array( 'jquery' ), $this->version, false );
		wp_enqueue_script( 'dcc-post-editor', plugin_dir_url( __FILE__ ) . 'assets/js/dcc-post-editor.js', array( 'jquery' ), $this->version, false );

	}
}
