<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.devpri.com
 * @since      1.0.0
 *
 * @package    Devpri_Custom_Code
 * @subpackage Devpri_Custom_Code/admin/includes
 */

class Devpri_Custom_Code_Post {

	/**
	 * Create custom post type
	 *
	 * @since    1.0.0
	 */
	public function create_post_type() {

		register_post_type(DCC_CUSTOM_POST_NAME,
		    array(
		    	'labels' => array(
		    		'name' => __('Devpri Custom Code'),
		    		'singular_name' => __( 'Custom Code', 'devpri-custom-code' ),
		    		'all_items' => __( 'Custom Code', 'devpri-custom-code' ),
		    	),
		    	'supports' 			  => array( 'title', 'revisions' ),
		    	'public' 			  => true,
		    	'has_archive'		  => false,
		    	'rewrite' 			  => false,
		    	'exclude_from_search' => true,
				'show_in_admin_bar'   => true,
				'show_in_menu'        => true,
				'menu_icon'           => 'dashicons-welcome-view-site',
		    	'publicly_queryable'  => false,
				'query_var'           => true
		    )
		);
	}

	/**
	 * Create meta boxes
	 *
	 * @since    1.0.0
	 */
	public function create_meta_boxes()
	{

        add_meta_box(
            'content',
            __('Content', 'devpri-custom-code'),
            array( $this,'content_editor_meta_box'),
            'devpri_custom_code', 'advanced', 'high'
        );
        
        add_meta_box(
            'options',
            __('Options', 'devpri-custom-code'),
            array($this,'options_meta_box'),
            'devpri_custom_code', 'side', 'default'
        );
	}

	/**
	 * Content meta box
	 *
	 * @since    1.0.0
	 */
	public function content_editor_meta_box( $post ) {
    	
    	global $post;
        
        $settings = array(
            'media_buttons' => false,
            'textarea_name'=> 'content',
            'tabindex' => 1,
            'tinymce' => false,
            'quicktags' => false,
            'editor_class' => 'dcc-editor',
        );
        
        $content_type = esc_attr( get_post_meta( $post->ID, '_content_type', true ));
       	
       	include( plugin_dir_path( __FILE__ ) . '/views/meta-boxes/content.php' );
    }

    /**
	 * Assignment meta box
	 *
	 * @since    1.0.0
	 */
	public function assignment_meta_box( $post ) {
 
    }

    /**
	 * Position meta box
	 *
	 * @since    1.0.0
	 */
    public function options_meta_box( $post ) {
    	$position = esc_attr( get_post_meta( $post->ID, '_position', true ));
    	$custom_action = esc_attr( get_post_meta( $post->ID, '_custom_action', true ));
    	$priority = esc_attr( get_post_meta( $post->ID, '_priority', true ));

		if(empty($priority)) {
			$priority = 10;
		}

		include( plugin_dir_path( __FILE__ ) . '/views/meta-boxes/options.php' );
    }

    /**
	 * Save Post
	 *
	 * @since    1.0.0
	 */
    public function save_post( $post_id ) {
	    
	    $post = get_post($post_id);
	    
	    if(	!wp_verify_nonce( $_POST['devpri-custom-code-nonce'], 'devpri-custom-code-' . $post_id->id )) {
	    	return;
	    }

	    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
        	return;
    	}

	    $content_type = wp_kses_post($_POST['content_type']);
	    $position = sanitize_text_field($_POST['position']);
	    $custom_action = sanitize_text_field($_POST['custom_action']);
	    $priority = intval($_POST['priority']);

    	update_post_meta( $post_id, '_content_type', $content_type );
    	update_post_meta( $post_id, '_position', $position );
    	update_post_meta( $post_id, '_custom_action', $custom_action );
    	update_post_meta( $post_id, '_priority', $priority );
    }

    /**
	 * Set columns
	 *
	 * @since    1.0.0
	 */
    public function set_custom_columns( $columns ) {
    	unset( $columns['date'] );
    	$columns['type'] = __( 'Type' );
    	$columns['position'] = __( 'Position' );
    	$columns['date'] = __( 'Date' );
    	return $columns;
	}

	/**
	 * Custom columns
	 *
	 * @since    1.0.0
	 */
	public function custom_columns( $column, $post_id ) {
	    switch ( $column ) {
	        case 'type' :
	        	$type = get_post_meta( $post_id , '_content_type' , true );
	            echo '<span class="dcc-type-' . $type . '">' . $type . '</span>'; 
	            break;
	        case 'position' :
	        	$position = get_post_meta( $post_id , '_position' , true );
	        	$custom_action = get_post_meta( $post_id , '_custom_action' , true );
	        	if ($position === 'custom') {
	        		$position = $position.'['.$custom_action.']';
	        	}
	            echo '<span class="dcc-position">' . $position . '</span>'; 
	            break;
	    }
	}
}
