<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.devpri.com
 * @since      1.0.0
 *
 * @package    Devpri_Custom_Code
 * @subpackage Devpri_Custom_Code/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Devpri_Custom_Code
 * @subpackage Devpri_Custom_Code/public
 * @author     Devpri <contact@devpri.com>
 */
class Devpri_Custom_Code_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($plugin_name, $version)
	{
		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function init()
	{
		$args = array(
		  'post_type'   => DCC_CUSTOM_POST_NAME,
		);
 
		$posts = get_posts( $args );
		foreach ($posts as $key => $post) {
			$meta = get_post_meta( $post->ID );
			$position = $meta['_position'][0];
			$custom_action = $meta['_custom_action'][0];
			$content_type = $meta['_content_type'][0];
			$action = $this->get_action( $position, $content_type, $custom_action );
			$this->display_code( $post, $content_type, $action );
		}
	}

	/**
	 * Get action name
	 *
	 * @since    1.0.0
	 */
	public function get_action( $position, $content_type ) {
		$action = 'wp_head';
		if ($position === 'footer') {
			$action = 'wp_footer';
		} elseif ( $position === 'custom' && $content_type === 'html') {
			$action = $custom_action;
		}
		return $action;
	}

	/**
	 * Display code
	 *
	 * @since    1.0.0
	 */
	public function display_code($post, $type, $action) {
		$content = $post->post_content;
		add_action( $action , function () use ( $post, $content, $file, $type) {
			switch ( $type ) {
		        case 'html' :
		        	echo $content;
		            break;
		        case 'js' :
		        	echo $this->inline_js($content);
		            break;
		        case 'css' :
					echo $this->inline_css($content);
		            break;
	    	}
		});
	}

	/**
	 * Inline CSS code
	 *
	 * @since    1.0.0
	 */
	public function inline_css($content) {
		$css  = '<style>';
		$css .= $content;
		$css .= '</style>';
		return $css; 
	}

	/**
	 * Inline JS code
	 *
	 * @since    1.0.0
	 */
	public function inline_js($content) {
		$js  = '<script>';
		$js .= $content;
		$js .= '</script>';
		return $js; 
	}
}
